==> electron-is-snap-1.0.2.tgz: package/README.md <==
<p align="center">
  <a href="https://cdn.itwcreativeworks.com/assets/itw-creative-works/images/logo/itw-creative-works-brandmark-black-x.svg">
    <img src="https://cdn.itwcreativeworks.com/assets/itw-creative-works/images/logo/itw-creative-works-brandmark-black-x.svg" width="100px">
  </a>
</p>

<p align="center">
  <img src="https://img.shields.io/github/package-json/v/itw-creative-works/electron-is-snap.svg">
  <br>
  <img src="https://img.shields.io/david/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/david/dev/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/bundlephobia/min/electron-is-snap.svg">
  <img src="https://img.shields.io/codeclimate/maintainability-percentage/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/npm/dm/electron-is-snap.svg">
  <img src="https://img.shields.io/node/v/electron-is-snap.svg">
  <img src="https://img.shields.io/website/https/itwcreativeworks.com.svg">
  <img src="https://img.shields.io/github/license/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/github/contributors/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/github/last-commit/itw-creative-works/electron-is-snap.svg">
  <br>
  <br>
  <a href="https://itwcreativeworks.com">Site</a> | <a href="https://www.npmjs.com/package/electron-is-snap">NPM Module</a> | <a href="https://github.com/itw-creative-works/electron-is-snap">GitHub Repo</a>
  <br>
  <br>
  <strong>Electron is Snap</strong> is an NPM module for Electron developers that helps you check if your project is running as a <strong>Linux Snap</strong> app.
</p>

## Install
Install with npm:
```shell
npm install electron-is-snap
```

## Features
* Check if your app is running in a **Linux Snap** environment
* Works in the **main** process and the **renderer** process
* Should work for non-Electron projects too

## Example Setup
After installing via npm, simply `require` the library and begin enjoying this simple tool 🧰.
```js
// In your main.js or renderer.js file
const isSnap = require('electron-is-snap').isSnap;

// Output: boolean
```
## Final Words
If you are still having difficulty, we would love for you to post a question to [the Electron is Snap issues page](https://github.com/itw-creative-works/electron-is-snap/issues). It is much easier to answer questions that include your code and relevant files! So if you can provide them, we'd be extremely grateful (and more likely to help you find the answer!)

A special thanks to [electron-is-packaged](https://github.com/ganeshrvel/npm-electron-is-packaged) for inspiring **electron-is-snap** and providing a structure for Electron apps checking if they are running in **Snap**.

## Projects Using this Library
[Somiibo](https://somiibo.com/): A Social Media Bot with an open-source module library. <br>
[JekyllUp](https://jekyllup.com/): A website devoted to sharing the best Jekyll themes. <br>
[Slapform](https://slapform.com/): A backend processor for your HTML forms on static sites. <br>
[Sniips](https://sniips.com/): A modern, hackable snippet manager <br>
[Proxifly](https://proxifly.com/): An API to get free proxies for your services. <br>
[Optiic](https://optiic.dev/): A free OCR image processing API. <br>
[SoundGrail Music App](https://app.soundgrail.com/): A resource for producers, musicians, and DJs. <br>

Ask us to have your project listed! :)

## Other Great Libraries
[node-powertools](https://www.npmjs.com/package/node-powertools): An NPM module for backend and frontend developers that exposes powerful utilities and tools. <br>
[optiic](https://www.npmjs.com/package/optiic): An OCR image processing API. <br>
[proxifly](https://www.npmjs.com/package/proxifly): An API to find proxies for your apps. <br>
[slapform](https://www.npmjs.com/package/slapform): A form backend API. <br>

==> electron-is-snap-1.0.3.tgz: package/README.md <==
<p align="center">
  <a href="https://cdn.itwcreativeworks.com/assets/itw-creative-works/images/logo/itw-creative-works-brandmark-black-x.svg">
    <img src="https://cdn.itwcreativeworks.com/assets/itw-creative-works/images/logo/itw-creative-works-brandmark-black-x.svg" width="100px">
  </a>
</p>

<p align="center">
  <img src="https://img.shields.io/github/package-json/v/itw-creative-works/electron-is-snap.svg">
  <br>
  <img src="https://img.shields.io/librariesio/release/npm/electron-is-snap.svg">
  <img src="https://img.shields.io/bundlephobia/min/electron-is-snap.svg">
  <img src="https://img.shields.io/codeclimate/maintainability-percentage/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/npm/dm/electron-is-snap.svg">
  <img src="https://img.shields.io/node/v/electron-is-snap.svg">
  <img src="https://img.shields.io/website/https/itwcreativeworks.com.svg">
  <img src="https://img.shields.io/github/license/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/github/contributors/itw-creative-works/electron-is-snap.svg">
  <img src="https://img.shields.io/github/last-commit/itw-creative-works/electron-is-snap.svg">
  <br>
  <br>
  <a href="https://itwcreativeworks.com">Site</a> | <a href="https://www.npmjs.com/package/electron-is-snap">NPM Module</a> | <a href="https://github.com/itw-creative-works/electron-is-snap">GitHub Repo</a>
  <br>
  <br>
  <strong>Electron is Snap</strong> is an NPM module for Electron developers that helps you check if your project is running as a <strong>Linux Snap</strong> app.
</p>

## Install
Install with npm:
```shell
npm install electron-is-snap
```

## Features
* Check if your app is running in a **Linux Snap** environment
* Works in the **main** process and the **renderer** process
* Should work for non-Electron projects too

## Example Setup
After installing via npm, simply `require` the library and begin enjoying this simple tool 🧰.
```js
// In your main.js or renderer.js file
const isSnap = require('electron-is-snap').isSnap;

// Output: boolean
```
## Final Words
If you are still having difficulty, we would love for you to post a question to [the Electron is Snap issues page](https://github.com/itw-creative-works/electron-is-snap/issues). It is much easier to answer questions that include your code and relevant files! So if you can provide them, we'd be extremely grateful (and more likely to help you find the answer!)

A special thanks to [electron-is-packaged](https://github.com/ganeshrvel/npm-electron-is-packaged) for inspiring **electron-is-snap** and providing a structure for Electron apps checking if they are running in **Snap**.

## Projects Using this Library
[Somiibo](https://somiibo.com/): A Social Media Bot with an open-source module library. <br>
[JekyllUp](https://jekyllup.com/): A website devoted to sharing the best Jekyll themes. <br>
[Slapform](https://slapform.com/): A backend processor for your HTML forms on static sites. <br>
[Sniips](https://sniips.com/): A modern, hackable snippet manager <br>
[Proxifly](https://proxifly.com/): An API to get free proxies for your services. <br>
[Optiic](https://optiic.dev/): A free OCR image processing API. <br>
[SoundGrail Music App](https://app.soundgrail.com/): A resource for producers, musicians, and DJs. <br>

Ask us to have your project listed! :)

## Other Great Libraries
[node-powertools](https://www.npmjs.com/package/node-powertools): An NPM module for backend and frontend developers that exposes powerful utilities and tools. <br>
[optiic](https://www.npmjs.com/package/optiic): An OCR image processing API. <br>
[proxifly](https://www.npmjs.com/package/proxifly): An API to find proxies for your apps. <br>
[slapform](https://www.npmjs.com/package/slapform): A form backend API. <br>
